<?php

namespace Drupal\ebt_bootstrap_button\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\ebt_core\Plugin\Field\FieldWidget\EbtSettingsDefaultWidget;

/**
 * Plugin implementation of the 'ebt_settings_bootstrap_button' widget.
 *
 * @FieldWidget(
 *   id = "ebt_settings_bootstrap_button",
 *   label = @Translation("EBT Bootstrap Button settings"),
 *   field_types = {
 *     "ebt_settings"
 *   }
 * )
 */
class EbtSettingsBootstrapButtonWidget extends EbtSettingsDefaultWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);

    $element['ebt_settings']['open_in_new_tab'] = [
      '#title' => $this->t('Open the link in a new tab'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['open_in_new_tab']) ? $items[$delta]->ebt_settings['open_in_new_tab'] : NULL,
    ];

    $element['ebt_settings']['add_nofollow'] = [
      '#title' => $this->t('Add "nofollow" option to the link'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['add_nofollow']) ? $items[$delta]->ebt_settings['add_nofollow'] : NULL,
    ];

    $element['ebt_settings']['alignment'] = [
      '#title' => $this->t('Alignment'),
      '#type' => 'radios',
      '#options' => [
        'left' => 'Left',
        'center' => 'Center',
        'right' => 'Right',
      ],
      '#default_value' => isset($items[$delta]->ebt_settings['alignment']) ? $items[$delta]->ebt_settings['alignment'] : 'left',
    ];

    $element['ebt_settings']['button_type'] = [
      '#title' => $this->t('Button Type'),
      '#type' => 'radios',
      '#options' => [
        'primary' => 'Primary',
        'secondary' => 'Secondary',
        'success' => 'Success',
        'danger' => 'Danger',
        'warning' => 'Warning',
        'info' => 'Info',
        'light' => 'Light',
        'dark' => 'Dark',
        'link' => 'Link',
      ],
      '#default_value' => isset($items[$delta]->ebt_settings['button_type']) ? $items[$delta]->ebt_settings['button_type'] : 'primary',
    ];

    $element['ebt_settings']['outline_button'] = [
      '#title' => $this->t('Outline Button'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['outline_button']) ? $items[$delta]->ebt_settings['outline_button'] : NULL,
    ];

    $element['ebt_settings']['active_button'] = [
      '#title' => $this->t('Active Button'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['active_button']) ? $items[$delta]->ebt_settings['active_button'] : NULL,
    ];

    $element['ebt_settings']['disable_button'] = [
      '#title' => $this->t('Disable Button'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['disable_button']) ? $items[$delta]->ebt_settings['disable_button'] : NULL,
      '#description' => $this->t("Links don’t support the disabled attribute, it will add the .disabled class to make it visually appear disabled."),
    ];

    $element['ebt_settings']['size'] = [
      '#title' => $this->t('Size'),
      '#type' => 'radios',
      '#options' => [
        'size-default' => 'Default',
        'btn-sm' => 'Small',
        'btn-lg' => 'Large',
      ],
      '#default_value' => isset($items[$delta]->ebt_settings['size']) ? $items[$delta]->ebt_settings['size'] : 'size-default',
    ];

    $element['ebt_settings']['stetched'] = [
      '#title' => $this->t('Stretched'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['stetched']) ? $items[$delta]->ebt_settings['stetched'] : NULL,
    ];

    $element['ebt_settings']['custom_class_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Custom class name'),
      '#default_value' => isset($items[$delta]->ebt_settings['custom_class_name']) ? $items[$delta]->ebt_settings['custom_class_name'] : '',
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as &$value) {
      $value += ['ebt_settings' => []];
    }
    return $values;
  }

}
